@@ -24,28 +24,38 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import os.path
-
+import pathlib
 from cerebralcortex.core.config_manager.config_handler import ConfigHandler
 
 
 class Configuration(ConfigHandler):
-    def __init__(self, config_dir:str, config_file_name:str="cerebralcortex.yml"):
+    def __init__(self, config_dir:str, cc_configs:dict="", config_file_name:str="cerebralcortex.yml"):
         """
         Constructor
         Args:
             config_dir (str): Directory path of cerebralcortex configuration files.
+            cc_configs (dict or str): if sets to cc_configs="default" all defaults configs would be loaded. Or you can provide a dict of all available cc_configs as a param
             config_file_name (str): configuration file name that should be loaded
         """
 
-        if config_dir[-1]!="/":
-            config_dir+="/"
+        if cc_configs=="default":
+            self.load_file(str(pathlib.Path(__file__).parent.absolute())+"/default.yml")
+        elif isinstance(cc_configs, dict):
+            self.load_file(str(pathlib.Path(__file__).parent.absolute())+"/default.yml")
+            self.config.update(cc_configs)
 
-        self.config_filepath = config_dir+config_file_name
+        elif config_dir:
+            if config_dir[-1]!="/":
+                config_dir+="/"
 
-        if not os.path.exists(self.config_filepath):
-            raise Exception(self.config_filepath+" does not exist. Please check configuration directory path and configuration file name.")
+            self.config_filepath = config_dir+config_file_name
 
-        if config_dir is not None:
-            self.load_file(self.config_filepath)
+            if not os.path.exists(self.config_filepath):
+                raise Exception(self.config_filepath+" does not exist. Please check configuration directory path and configuration file name.")
+
+            if config_dir is not None:
+                self.load_file(self.config_filepath)
+            else:
+                self.config = None
         else:
-            self.config = None
+            raise Exception("Cannot load configuration files.")
