@@ -29,7 +29,6 @@ import mysql.connector
 import mysql.connector.pooling
 
 from cerebralcortex.core.data_manager.sql.cache_handler import CacheHandler
-from cerebralcortex.core.data_manager.sql.kafka_offsets_handler import KafkaOffsetsHandler
 from cerebralcortex.core.data_manager.sql.stream_handler import StreamHandler
 from cerebralcortex.core.data_manager.sql.metadata_handler import MetadataHandler
 from cerebralcortex.core.data_manager.sql.users_handler import UserHandler
@@ -37,7 +36,7 @@ from cerebralcortex.core.log_manager.log_handler import LogTypes
 from cerebralcortex.core.data_manager.sql.data_ingestion_handler import DataIngestionHandler
 
 
-class SqlData(StreamHandler, UserHandler, KafkaOffsetsHandler, CacheHandler, DataIngestionHandler, MetadataHandler):
+class SqlData(StreamHandler, UserHandler, CacheHandler, DataIngestionHandler, MetadataHandler):
     def __init__(self, CC):
         """
         Constructor
