@@ -24,6 +24,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import uuid
+import os
 import warnings
 from datetime import datetime
 from typing import List
@@ -44,24 +45,31 @@ from cerebralcortex.core.metadata_manager.stream.metadata import Metadata
 
 class Kernel:
 
-    def __init__(self, configs_dir_path: str, study_name:str, new_study:bool=False, auto_offset_reset: str = "largest", enable_spark:bool=True, enable_spark_ui=False):
+    def __init__(self, configs_dir_path: str="", cc_configs:dict=None, study_name:str="default", new_study:bool=False, enable_spark:bool=True, enable_spark_ui=False, mprov=False):
         """
         CerebralCortex constructor
 
         Args:
             configs_dir_path (str): Directory path of cerebralcortex configurations.
+            cc_configs (dict or str): if sets to cc_configs="default" all defaults configs would be loaded. Or you can provide a dict of all available cc_configs as a param
             study_name (str): name of the study. If there is no study, you can pass study name as study_name="default"
             new_study (bool): create a new study with study_name if it does not exist
-            auto_offset_reset (str): Kafka offset. Acceptable parameters are smallest or largest (default=largest)
             enable_spark (bool): enable spark
             enable_spark_ui (bool): enable spark ui
+            mprov (bool): if set to true then running algorithms will store provenance information in pennprov server. setup pennprov server (https://bitbucket.org/penndb/pennprov/src/master/) if you set this to True
         Raises:
             ValueError: If configuration_filepath is None or empty.
         Examples:
             >>> CC = Kernel("/directory/path/of/configs/", study_name="default")
         """
-        if configs_dir_path is None or configs_dir_path == "":
-            raise ValueError("config_file path cannot be None or blank.")
+        if not configs_dir_path and not cc_configs:
+            raise ValueError("Please provide configs_dir_path or cc_configs.")
+        elif configs_dir_path and cc_configs:
+            raise ValueError("Provide only configs_dir_path OR cc_configs.")
+
+        self.config_filepath = configs_dir_path
+        self.study_name = study_name
+        self.config = Configuration(configs_dir_path, cc_configs).config
 
         if enable_spark:
             self.sparkContext = get_or_create_sc(enable_spark_ui=enable_spark_ui)
@@ -72,15 +80,22 @@ class Kernel:
             self.sqlContext = None
             self.sparkSession = None
 
+        if mprov:
+            if self.config["mprov"]=="pennprov":
+                os.environ["MPROV_HOST"] = self.config["pennprov"]["host"]
+                os.environ["MPROV_USER"] = self.config["pennprov"]["user"]
+                os.environ["MPROV_PASSWORD"] = self.config["pennprov"]["password"]
+                os.environ["ENABLE_MPROV"] = "True"
+            elif self.config["mprov"]=="none":
+                os.environ["ENABLE_MPROV"] = "False"
+            else:
+                raise ValueError("Please check cerebralcortex.yml file. mprov is not properly configured.")
+
         self.new_study = new_study
 
         if not study_name:
             raise Exception("Study name cannot be None.")
 
-        self.config_filepath = configs_dir_path
-        self.study_name = study_name
-        self.config = Configuration(configs_dir_path).config
-
         self.debug = self.config["cc"]["debug"]
         self.logging = CCLogging(self)
         self.logtypes = LogTypes()
@@ -527,41 +542,6 @@ class Kernel:
         """
         return self.SqlData.encrypt_user_password(user_password)
 
-    ################### KAFKA RELATED METHODS ##################################
-
-    def store_or_update_Kafka_offset(self, topic_partition: str, offset_start: str, offset_until: str)->bool:
-        """
-        Store or Update kafka topic offsets. Offsets are used to track what messages have been processed.
-
-        Args:
-            topic (str): name of the kafka topic
-            topic_partition (str): partition number
-            offset_start (str): starting of offset
-            offset_until (str): last processed offset
-        Raises:
-            ValueError: All params are required.
-            Exception: Cannot add/update kafka offsets because ERROR-MESSAGE
-        Returns:
-            bool: returns True if offsets are add/updated or throws an exception.
-
-        """
-        self.SqlData.store_or_update_Kafka_offset(topic_partition, offset_start, offset_until)
-
-    def get_kafka_offsets(self) -> List[dict]:
-        """
-        Get last stored kafka offsets
-
-        Returns:
-            list[dict]: list of kafka offsets. This method will return empty list if topic does not exist and/or no offset is stored for the topic.
-        Raises:
-            ValueError: Topic name cannot be empty/None
-        Examples:
-            >>> CC = Kernel("/directory/path/of/configs/", study_name="default")
-            >>> CC.get_kafka_offsets("live-data")
-            >>> [{"id","topic", "topic_partition", "offset_start", "offset_until", "offset_update_time"}]
-        """
-        return self.SqlData.get_kafka_offsets()
-
     ###########################################################################
     #                      OBJECTS DATA MANAGER METHODS                       #
     ###########################################################################
